@@ -19,21 +19,22 @@
 
 #include "bookmarklistview.h"
 #include "globalbookmarkmanager.h"
-#include "kbookmarkmodel/model.h"
-#include "toplevel.h" // for KEBApp
-#include "settings.h"
 #include "kbookmarkmodel/commands.h"
+#include "kbookmarkmodel/model.h"
+#include "settings.h"
+#include "toplevel.h" // for KEBApp
 
-#include <QHeaderView>
+#include <QBrush>
 #include <QContextMenuEvent>
+#include <QHeaderView>
 #include <QItemSelection>
 #include <QMenu>
-#include <QBrush>
 
 #include "keditbookmarks_debug.h"
 
-BookmarkFolderView::BookmarkFolderView( BookmarkListView * view, QWidget * parent )
-    : KBookmarkView(parent), mview(view)
+BookmarkFolderView::BookmarkFolderView(BookmarkListView *view, QWidget *parent)
+    : KBookmarkView(parent)
+    , mview(view)
 {
     mmodel = new BookmarkFolderViewFilterModel(parent);
     mmodel->setSourceModel(view->model());
@@ -41,87 +42,78 @@ BookmarkFolderView::BookmarkFolderView( BookmarkListView * view, QWidget * paren
     header()->setVisible(false);
     setRootIsDecorated(false);
     setDropIndicatorShown(true);
-    setCurrentIndex( mmodel->index(0,0, QModelIndex()));
+    setCurrentIndex(mmodel->index(0, 0, QModelIndex()));
 
     connect(mmodel, &BookmarkFolderViewFilterModel::modelReset, this, &BookmarkFolderView::slotReset);
 }
 
-
 BookmarkFolderView::~BookmarkFolderView()
 {
-
 }
 
-void BookmarkFolderView::selectionChanged ( const QItemSelection & deselected, const QItemSelection & selected)
+void BookmarkFolderView::selectionChanged(const QItemSelection &deselected, const QItemSelection &selected)
 {
-    const QModelIndexList & list = selectionModel()->selectedIndexes();
-    if(list.count())
-        mview->setRootIndex( mmodel->mapToSource(list.at(0)) );
+    const QModelIndexList &list = selectionModel()->selectedIndexes();
+    if (list.count())
+        mview->setRootIndex(mmodel->mapToSource(list.at(0)));
     else
-        mview->setRootIndex( QModelIndex());
+        mview->setRootIndex(QModelIndex());
     KBookmarkView::selectionChanged(deselected, selected);
 }
 
 void BookmarkFolderView::slotReset()
 {
-    setCurrentIndex( mmodel->index(0,0, QModelIndex()));
+    setCurrentIndex(mmodel->index(0, 0, QModelIndex()));
     loadFoldedState();
 }
 
-KBookmark BookmarkFolderView::bookmarkForIndex(const QModelIndex & idx) const
+KBookmark BookmarkFolderView::bookmarkForIndex(const QModelIndex &idx) const
 {
-    qCDebug(KEDITBOOKMARKS_LOG)<<"BookmarkFolderView::bookmarkForIndex"<<idx;
-    const QModelIndex & index = mmodel->mapToSource(idx);
+    qCDebug(KEDITBOOKMARKS_LOG) << "BookmarkFolderView::bookmarkForIndex" << idx;
+    const QModelIndex &index = mmodel->mapToSource(idx);
     return static_cast<KBookmarkModel *>(mmodel->sourceModel())->bookmarkForIndex(index);
 }
 
 /********/
 
-
-BookmarkListView::BookmarkListView( QWidget * parent )
+BookmarkListView::BookmarkListView(QWidget *parent)
     : KBookmarkView(parent)
 {
     setDragEnabled(true);
 }
 
-
-void BookmarkListView::setModel(QAbstractItemModel * model)
+void BookmarkListView::setModel(QAbstractItemModel *model)
 {
     KBookmarkView::setModel(model);
 }
 
-KBookmarkModel* BookmarkListView::bookmarkModel() const
+KBookmarkModel *BookmarkListView::bookmarkModel() const
 {
-    return dynamic_cast<KBookmarkModel*>(QTreeView::model());
+    return dynamic_cast<KBookmarkModel *>(QTreeView::model());
 }
 
-KBookmark BookmarkListView::bookmarkForIndex(const QModelIndex & idx) const
+KBookmark BookmarkListView::bookmarkForIndex(const QModelIndex &idx) const
 {
     return bookmarkModel()->bookmarkForIndex(idx);
 }
 
-
 BookmarkListView::~BookmarkListView()
 {
     saveColumnSetting();
 }
 
-void BookmarkListView::contextMenuEvent ( QContextMenuEvent * e )
+void BookmarkListView::contextMenuEvent(QContextMenuEvent *e)
 {
     QModelIndex index = indexAt(e->pos());
     KBookmark bk;
-    if(index.isValid())
+    if (index.isValid())
         bk = bookmarkForIndex(index);
 
-    QMenu* popup;
-    if( !index.isValid()
-       || (bk.address() == GlobalBookmarkManager::self()->root().address())
-       || (bk.isGroup())) //FIXME add empty folder padder
+    QMenu *popup;
+    if (!index.isValid() || (bk.address() == GlobalBookmarkManager::self()->root().address()) || (bk.isGroup())) // FIXME add empty folder padder
     {
         popup = KEBApp::self()->popupMenuFactory("popup_folder");
-    }
-    else
-    {
+    } else {
         popup = KEBApp::self()->popupMenuFactory("popup_bookmark");
     }
     if (popup)
@@ -138,16 +130,16 @@ void BookmarkListView::loadColumnSetting()
 
 void BookmarkListView::saveColumnSetting()
 {
-    KEBSettings::setName( header()->sectionSize(KEBApp::NameColumn));
-    KEBSettings::setURL( header()->sectionSize(KEBApp::UrlColumn));
-    KEBSettings::setComment( header()->sectionSize(KEBApp::CommentColumn));
-    KEBSettings::setStatus( header()->sectionSize(KEBApp::StatusColumn));
+    KEBSettings::setName(header()->sectionSize(KEBApp::NameColumn));
+    KEBSettings::setURL(header()->sectionSize(KEBApp::UrlColumn));
+    KEBSettings::setComment(header()->sectionSize(KEBApp::CommentColumn));
+    KEBSettings::setStatus(header()->sectionSize(KEBApp::StatusColumn));
     KEBSettings::self()->save();
 }
 
 /************/
 
-BookmarkFolderViewFilterModel::BookmarkFolderViewFilterModel(QObject * parent)
+BookmarkFolderViewFilterModel::BookmarkFolderViewFilterModel(QObject *parent)
     : QSortFilterProxyModel(parent)
 {
 }
@@ -161,29 +153,23 @@ bool BookmarkFolderViewFilterModel::dropMimeData(const QMimeData *data, Qt::Drop
 {
     QModelIndex dropDestProxyIndex;
     bool isInsertBetweenOp = false;
-    if(row == -1)
-    {
+    if (row == -1) {
         dropDestProxyIndex = parent;
-    }
-    else
-    {
+    } else {
         dropDestProxyIndex = index(row, column, parent);
         isInsertBetweenOp = true;
     }
     QModelIndex dropDestIndex = mapToSource(dropDestProxyIndex);
-    if (!isInsertBetweenOp)
-    {
+    if (!isInsertBetweenOp) {
         // Just dropping it onto dropDestIndex - ignore row and column.
-        return sourceModel()->dropMimeData( data, action, -1, -1, dropDestIndex);
-    }
-    else
-    {
+        return sourceModel()->dropMimeData(data, action, -1, -1, dropDestIndex);
+    } else {
         // Dropping before dropDestIndex.  We want to keep row and column
         // relative to the parent.
         // I'm reasonably certain the parent must be valid in this case.  If you get a crash here - nag me!
         Q_ASSERT(parent.isValid());
         QModelIndex dropDestParentIndex = mapToSource(parent);
-        return sourceModel()->dropMimeData( data, action, dropDestIndex.row(), dropDestIndex.column(), dropDestParentIndex);
+        return sourceModel()->dropMimeData(data, action, dropDestIndex.row(), dropDestIndex.column(), dropDestParentIndex);
     }
 }
 
@@ -191,19 +177,17 @@ BookmarkFolderViewFilterModel::~BookmarkFolderViewFilterModel()
 {
 }
 
-bool BookmarkFolderViewFilterModel::filterAcceptsColumn ( int source_column, const QModelIndex & source_parent ) const
+bool BookmarkFolderViewFilterModel::filterAcceptsColumn(int source_column, const QModelIndex &source_parent) const
 {
     Q_UNUSED(source_parent);
 
-    //Show name, hide everything else
+    // Show name, hide everything else
     return (source_column == 0);
 }
 
-bool BookmarkFolderViewFilterModel::filterAcceptsRow ( int source_row, const QModelIndex & source_parent ) const
+bool BookmarkFolderViewFilterModel::filterAcceptsRow(int source_row, const QModelIndex &source_parent) const
 {
     QModelIndex index = sourceModel()->index(source_row, 0, source_parent);
     const KBookmark bk = index.data(KBookmarkModel::KBookmarkRole).value<KBookmark>();
     return bk.isGroup();
 }
-
-
